metapho.metapho.Image

Package metapho :: Module metapho :: Class Image |
[hide private]

# Class Image

source code

An image, with additional info such as rotation and tags.

Instance Methods | [hide private]
__init__(self, filename, displayed=True) Initialize an image filename. | source code
__repr__(self) | source code
delete(self) Delete the image file FROM DISK, and the image object from the imageList. | source code

Class Variables | [hide private]
| g_image_list = ``[``]``

Method Details | [hide private]

### __init__(self, filename, displayed=True) (Constructor) | source code
Initialize an image filename. Pass displayed=False if this image isn't to be shown in the current session, only used for remembering previously set tags.

### delete(self) | source code
Delete the image file FROM DISK, and the image object from the imageList. DOES NOT ASK FOR CONFIRMATION -- do that (if desired) from the calling program.